==> aspose-imaging-cloud-20.5.0.tar.gz: aspose-imaging-cloud-20.5.0/asposeimagingcloud/models/requests/__init__.py <==
from asposeimagingcloud.models.requests.add_search_image_request import AddSearchImageRequest
from asposeimagingcloud.models.requests.append_tiff_request import AppendTiffRequest
from asposeimagingcloud.models.requests.compare_images_request import CompareImagesRequest
from asposeimagingcloud.models.requests.convert_tiff_to_fax_request import ConvertTiffToFaxRequest
from asposeimagingcloud.models.requests.copy_file_request import CopyFileRequest
from asposeimagingcloud.models.requests.copy_folder_request import CopyFolderRequest
from asposeimagingcloud.models.requests.create_cropped_image_request import CreateCroppedImageRequest
from asposeimagingcloud.models.requests.create_deskewed_image_request import CreateDeskewedImageRequest
from asposeimagingcloud.models.requests.create_fax_tiff_request import CreateFaxTiffRequest
from asposeimagingcloud.models.requests.create_folder_request import CreateFolderRequest
from asposeimagingcloud.models.requests.create_grayscaled_image_request import CreateGrayscaledImageRequest
from asposeimagingcloud.models.requests.create_image_features_request import CreateImageFeaturesRequest
from asposeimagingcloud.models.requests.create_image_frame_range_request import CreateImageFrameRangeRequest
from asposeimagingcloud.models.requests.create_image_frame_request import CreateImageFrameRequest
from asposeimagingcloud.models.requests.create_image_search_request import CreateImageSearchRequest
from asposeimagingcloud.models.requests.create_image_tag_request import CreateImageTagRequest
from asposeimagingcloud.models.requests.create_modified_bmp_request import CreateModifiedBmpRequest
from asposeimagingcloud.models.requests.create_modified_emf_request import CreateModifiedEmfRequest
from asposeimagingcloud.models.requests.create_modified_gif_request import CreateModifiedGifRequest
from asposeimagingcloud.models.requests.create_modified_jpeg2000_request import CreateModifiedJpeg2000Request
from asposeimagingcloud.models.requests.create_modified_jpeg_request import CreateModifiedJpegRequest
from asposeimagingcloud.models.requests.create_modified_psd_request import CreateModifiedPsdRequest
from asposeimagingcloud.models.requests.create_modified_svg_request import CreateModifiedSvgRequest
from asposeimagingcloud.models.requests.create_modified_tiff_request import CreateModifiedTiffRequest
from asposeimagingcloud.models.requests.create_modified_web_p_request import CreateModifiedWebPRequest
from asposeimagingcloud.models.requests.create_modified_wmf_request import CreateModifiedWmfRequest
from asposeimagingcloud.models.requests.create_object_bounds_request import CreateObjectBoundsRequest
from asposeimagingcloud.models.requests.create_resized_image_request import CreateResizedImageRequest
from asposeimagingcloud.models.requests.create_rotate_flipped_image_request import CreateRotateFlippedImageRequest
from asposeimagingcloud.models.requests.create_saved_image_as_request import CreateSavedImageAsRequest
from asposeimagingcloud.models.requests.create_updated_image_request import CreateUpdatedImageRequest
from asposeimagingcloud.models.requests.create_visual_object_bounds_request import CreateVisualObjectBoundsRequest
from asposeimagingcloud.models.requests.create_web_site_image_features_request import CreateWebSiteImageFeaturesRequest
from asposeimagingcloud.models.requests.crop_image_request import CropImageRequest
from asposeimagingcloud.models.requests.delete_file_request import DeleteFileRequest
from asposeimagingcloud.models.requests.delete_folder_request import DeleteFolderRequest
from asposeimagingcloud.models.requests.delete_image_features_request import DeleteImageFeaturesRequest
from asposeimagingcloud.models.requests.delete_image_search_request import DeleteImageSearchRequest
from asposeimagingcloud.models.requests.delete_search_image_request import DeleteSearchImageRequest
from asposeimagingcloud.models.requests.deskew_image_request import DeskewImageRequest
from asposeimagingcloud.models.requests.download_file_request import DownloadFileRequest
from asposeimagingcloud.models.requests.extract_image_features_request import ExtractImageFeaturesRequest
from asposeimagingcloud.models.requests.extract_image_frame_properties_request import ExtractImageFramePropertiesRequest
from asposeimagingcloud.models.requests.extract_image_properties_request import ExtractImagePropertiesRequest
from asposeimagingcloud.models.requests.filter_effect_image_request import FilterEffectImageRequest
from asposeimagingcloud.models.requests.find_images_by_tags_request import FindImagesByTagsRequest
from asposeimagingcloud.models.requests.find_image_duplicates_request import FindImageDuplicatesRequest
from asposeimagingcloud.models.requests.find_similar_images_request import FindSimilarImagesRequest
from asposeimagingcloud.models.requests.get_disc_usage_request import GetDiscUsageRequest
from asposeimagingcloud.models.requests.get_files_list_request import GetFilesListRequest
from asposeimagingcloud.models.requests.get_file_versions_request import GetFileVersionsRequest
from asposeimagingcloud.models.requests.get_image_features_request import GetImageFeaturesRequest
from asposeimagingcloud.models.requests.get_image_frame_properties_request import GetImageFramePropertiesRequest
from asposeimagingcloud.models.requests.get_image_frame_range_request import GetImageFrameRangeRequest
from asposeimagingcloud.models.requests.get_image_frame_request import GetImageFrameRequest
from asposeimagingcloud.models.requests.get_image_properties_request import GetImagePropertiesRequest
from asposeimagingcloud.models.requests.get_image_search_status_request import GetImageSearchStatusRequest
from asposeimagingcloud.models.requests.get_object_bounds_request import GetObjectBoundsRequest
from asposeimagingcloud.models.requests.get_search_image_request import GetSearchImageRequest
from asposeimagingcloud.models.requests.get_visual_object_bounds_request import GetVisualObjectBoundsRequest
from asposeimagingcloud.models.requests.grayscale_image_request import GrayscaleImageRequest
from asposeimagingcloud.models.requests.http_request import HttpRequest
from asposeimagingcloud.models.requests.imaging_request import ImagingRequest
from asposeimagingcloud.models.requests.modify_bmp_request import ModifyBmpRequest
from asposeimagingcloud.models.requests.modify_emf_request import ModifyEmfRequest
from asposeimagingcloud.models.requests.modify_gif_request import ModifyGifRequest
from asposeimagingcloud.models.requests.modify_jpeg2000_request import ModifyJpeg2000Request
from asposeimagingcloud.models.requests.modify_jpeg_request import ModifyJpegRequest
from asposeimagingcloud.models.requests.modify_psd_request import ModifyPsdRequest
from asposeimagingcloud.models.requests.modify_svg_request import ModifySvgRequest
from asposeimagingcloud.models.requests.modify_tiff_request import ModifyTiffRequest
from asposeimagingcloud.models.requests.modify_web_p_request import ModifyWebPRequest
from asposeimagingcloud.models.requests.modify_wmf_request import ModifyWmfRequest
from asposeimagingcloud.models.requests.move_file_request import MoveFileRequest
from asposeimagingcloud.models.requests.move_folder_request import MoveFolderRequest
from asposeimagingcloud.models.requests.object_exists_request import ObjectExistsRequest
from asposeimagingcloud.models.requests.resize_image_request import ResizeImageRequest
from asposeimagingcloud.models.requests.rotate_flip_image_request import RotateFlipImageRequest
from asposeimagingcloud.models.requests.save_image_as_request import SaveImageAsRequest
from asposeimagingcloud.models.requests.storage_exists_request import StorageExistsRequest
from asposeimagingcloud.models.requests.update_image_features_request import UpdateImageFeaturesRequest
from asposeimagingcloud.models.requests.update_image_request import UpdateImageRequest
from asposeimagingcloud.models.requests.update_search_image_request import UpdateSearchImageRequest
from asposeimagingcloud.models.requests.upload_file_request import UploadFileRequest

==> aspose-imaging-cloud-21.11.0.tar.gz: aspose-imaging-cloud-21.11.0/asposeimagingcloud/models/requests/__init__.py <==
from asposeimagingcloud.models.requests.add_search_image_request import AddSearchImageRequest
from asposeimagingcloud.models.requests.append_tiff_request import AppendTiffRequest
from asposeimagingcloud.models.requests.compare_images_request import CompareImagesRequest
from asposeimagingcloud.models.requests.convert_image_request import ConvertImageRequest
from asposeimagingcloud.models.requests.convert_tiff_to_fax_request import ConvertTiffToFaxRequest
from asposeimagingcloud.models.requests.copy_file_request import CopyFileRequest
from asposeimagingcloud.models.requests.copy_folder_request import CopyFolderRequest
from asposeimagingcloud.models.requests.create_converted_image_request import CreateConvertedImageRequest
from asposeimagingcloud.models.requests.create_cropped_image_request import CreateCroppedImageRequest
from asposeimagingcloud.models.requests.create_deskewed_image_request import CreateDeskewedImageRequest
from asposeimagingcloud.models.requests.create_fax_tiff_request import CreateFaxTiffRequest
from asposeimagingcloud.models.requests.create_folder_request import CreateFolderRequest
from asposeimagingcloud.models.requests.create_grayscaled_image_request import CreateGrayscaledImageRequest
from asposeimagingcloud.models.requests.create_image_features_request import CreateImageFeaturesRequest
from asposeimagingcloud.models.requests.create_image_frame_range_request import CreateImageFrameRangeRequest
from asposeimagingcloud.models.requests.create_image_frame_request import CreateImageFrameRequest
from asposeimagingcloud.models.requests.create_image_search_request import CreateImageSearchRequest
from asposeimagingcloud.models.requests.create_image_tag_request import CreateImageTagRequest
from asposeimagingcloud.models.requests.create_modified_bmp_request import CreateModifiedBmpRequest
from asposeimagingcloud.models.requests.create_modified_emf_request import CreateModifiedEmfRequest
from asposeimagingcloud.models.requests.create_modified_gif_request import CreateModifiedGifRequest
from asposeimagingcloud.models.requests.create_modified_jpeg2000_request import CreateModifiedJpeg2000Request
from asposeimagingcloud.models.requests.create_modified_jpeg_request import CreateModifiedJpegRequest
from asposeimagingcloud.models.requests.create_modified_psd_request import CreateModifiedPsdRequest
from asposeimagingcloud.models.requests.create_modified_svg_request import CreateModifiedSvgRequest
from asposeimagingcloud.models.requests.create_modified_tiff_request import CreateModifiedTiffRequest
from asposeimagingcloud.models.requests.create_modified_web_p_request import CreateModifiedWebPRequest
from asposeimagingcloud.models.requests.create_modified_wmf_request import CreateModifiedWmfRequest
from asposeimagingcloud.models.requests.create_object_bounds_request import CreateObjectBoundsRequest
from asposeimagingcloud.models.requests.create_resized_image_request import CreateResizedImageRequest
from asposeimagingcloud.models.requests.create_rotate_flipped_image_request import CreateRotateFlippedImageRequest
from asposeimagingcloud.models.requests.create_updated_image_request import CreateUpdatedImageRequest
from asposeimagingcloud.models.requests.create_visual_object_bounds_request import CreateVisualObjectBoundsRequest
from asposeimagingcloud.models.requests.create_web_site_image_features_request import CreateWebSiteImageFeaturesRequest
from asposeimagingcloud.models.requests.crop_image_request import CropImageRequest
from asposeimagingcloud.models.requests.delete_file_request import DeleteFileRequest
from asposeimagingcloud.models.requests.delete_folder_request import DeleteFolderRequest
from asposeimagingcloud.models.requests.delete_image_features_request import DeleteImageFeaturesRequest
from asposeimagingcloud.models.requests.delete_image_search_request import DeleteImageSearchRequest
from asposeimagingcloud.models.requests.delete_search_image_request import DeleteSearchImageRequest
from asposeimagingcloud.models.requests.deskew_image_request import DeskewImageRequest
from asposeimagingcloud.models.requests.download_file_request import DownloadFileRequest
from asposeimagingcloud.models.requests.extract_image_features_request import ExtractImageFeaturesRequest
from asposeimagingcloud.models.requests.extract_image_frame_properties_request import ExtractImageFramePropertiesRequest
from asposeimagingcloud.models.requests.extract_image_properties_request import ExtractImagePropertiesRequest
from asposeimagingcloud.models.requests.filter_effect_image_request import FilterEffectImageRequest
from asposeimagingcloud.models.requests.find_images_by_tags_request import FindImagesByTagsRequest
from asposeimagingcloud.models.requests.find_image_duplicates_request import FindImageDuplicatesRequest
from asposeimagingcloud.models.requests.find_similar_images_request import FindSimilarImagesRequest
from asposeimagingcloud.models.requests.get_available_labels_request import GetAvailableLabelsRequest
from asposeimagingcloud.models.requests.get_disc_usage_request import GetDiscUsageRequest
from asposeimagingcloud.models.requests.get_files_list_request import GetFilesListRequest
from asposeimagingcloud.models.requests.get_file_versions_request import GetFileVersionsRequest
from asposeimagingcloud.models.requests.get_image_features_request import GetImageFeaturesRequest
from asposeimagingcloud.models.requests.get_image_frame_properties_request import GetImageFramePropertiesRequest
from asposeimagingcloud.models.requests.get_image_frame_range_request import GetImageFrameRangeRequest
from asposeimagingcloud.models.requests.get_image_frame_request import GetImageFrameRequest
from asposeimagingcloud.models.requests.get_image_properties_request import GetImagePropertiesRequest
from asposeimagingcloud.models.requests.get_image_search_status_request import GetImageSearchStatusRequest
from asposeimagingcloud.models.requests.get_object_bounds_request import GetObjectBoundsRequest
from asposeimagingcloud.models.requests.get_search_image_request import GetSearchImageRequest
from asposeimagingcloud.models.requests.get_visual_object_bounds_request import GetVisualObjectBoundsRequest
from asposeimagingcloud.models.requests.grayscale_image_request import GrayscaleImageRequest
from asposeimagingcloud.models.requests.http_request import HttpRequest
from asposeimagingcloud.models.requests.imaging_request import ImagingRequest
from asposeimagingcloud.models.requests.modify_bmp_request import ModifyBmpRequest
from asposeimagingcloud.models.requests.modify_emf_request import ModifyEmfRequest
from asposeimagingcloud.models.requests.modify_gif_request import ModifyGifRequest
from asposeimagingcloud.models.requests.modify_jpeg2000_request import ModifyJpeg2000Request
from asposeimagingcloud.models.requests.modify_jpeg_request import ModifyJpegRequest
from asposeimagingcloud.models.requests.modify_psd_request import ModifyPsdRequest
from asposeimagingcloud.models.requests.modify_svg_request import ModifySvgRequest
from asposeimagingcloud.models.requests.modify_tiff_request import ModifyTiffRequest
from asposeimagingcloud.models.requests.modify_web_p_request import ModifyWebPRequest
from asposeimagingcloud.models.requests.modify_wmf_request import ModifyWmfRequest
from asposeimagingcloud.models.requests.move_file_request import MoveFileRequest
from asposeimagingcloud.models.requests.move_folder_request import MoveFolderRequest
from asposeimagingcloud.models.requests.object_exists_request import ObjectExistsRequest
from asposeimagingcloud.models.requests.resize_image_request import ResizeImageRequest
from asposeimagingcloud.models.requests.rotate_flip_image_request import RotateFlipImageRequest
from asposeimagingcloud.models.requests.storage_exists_request import StorageExistsRequest
from asposeimagingcloud.models.requests.update_image_features_request import UpdateImageFeaturesRequest
from asposeimagingcloud.models.requests.update_image_request import UpdateImageRequest
from asposeimagingcloud.models.requests.update_search_image_request import UpdateSearchImageRequest
from asposeimagingcloud.models.requests.upload_file_request import UploadFileRequest
